# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bess_msg.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
import error_pb2 as error__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bess_msg.proto',
  package='bess.pb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x0e\x62\x65ss_msg.proto\x12\x07\x62\x65ss.pb\x1a\x19google/protobuf/any.proto\x1a\x0b\x65rror.proto\"\x0e\n\x0c\x45mptyRequest\".\n\rEmptyResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\"A\n\x0fVersionResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x0f\n\x07version\x18\x02 \x01(\t\"#\n\x13ImportPluginRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"#\n\x13UnloadPluginRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"C\n\x13ListPluginsResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\r\n\x05paths\x18\x02 \x03(\t\"\xda\x01\n\x13ListWorkersResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x41\n\x0eworkers_status\x18\x02 \x03(\x0b\x32).bess.pb.ListWorkersResponse.WorkerStatus\x1a\x61\n\x0cWorkerStatus\x12\x0b\n\x03wid\x18\x01 \x01(\x03\x12\x0c\n\x04\x63ore\x18\x02 \x01(\x03\x12\x0f\n\x07running\x18\x03 \x01(\x08\x12\x0f\n\x07num_tcs\x18\x04 \x01(\x03\x12\x14\n\x0csilent_drops\x18\x05 \x01(\x03\"@\n\x10\x41\x64\x64WorkerRequest\x12\x0b\n\x03wid\x18\x01 \x01(\x03\x12\x0c\n\x04\x63ore\x18\x02 \x01(\x03\x12\x11\n\tscheduler\x18\x03 \x01(\t\"#\n\x14\x44\x65stroyWorkerRequest\x12\x0b\n\x03wid\x18\x01 \x01(\x03\"\x96\x03\n\x0cTrafficClass\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x62locked\x18\x03 \x01(\x08\x12\x0e\n\x06policy\x18\x04 \x01(\t\x12\x10\n\x08resource\x18\x05 \x01(\t\x12\x12\n\x08priority\x18\x06 \x01(\x03H\x00\x12\x0f\n\x05share\x18\x07 \x01(\x03H\x00\x12\x0b\n\x03wid\x18\x08 \x01(\x03\x12/\n\x05limit\x18\t \x03(\x0b\x32 .bess.pb.TrafficClass.LimitEntry\x12\x36\n\tmax_burst\x18\n \x03(\x0b\x32#.bess.pb.TrafficClass.MaxBurstEntry\x12\x18\n\x10leaf_module_name\x18\x0b \x01(\t\x12\x1a\n\x12leaf_module_taskid\x18\x0c \x01(\x04\x1a,\n\nLimitEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a/\n\rMaxBurstEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x42\x05\n\x03\x61rg\"\x1d\n\x0eListTcsRequest\x12\x0b\n\x03wid\x18\x01 \x01(\x03\"\xc1\x01\n\x0fListTcsResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x43\n\x0e\x63lasses_status\x18\x02 \x03(\x0b\x32+.bess.pb.ListTcsResponse.TrafficClassStatus\x1aJ\n\x12TrafficClassStatus\x12$\n\x05\x63lass\x18\x01 \x01(\x0b\x32\x15.bess.pb.TrafficClass\x12\x0e\n\x06parent\x18\x02 \x01(\t\"\xf3\x02\n\"CheckSchedulingConstraintsResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\r\n\x05\x66\x61tal\x18\x02 \x01(\x08\x12N\n\nviolations\x18\x03 \x03(\x0b\x32:.bess.pb.CheckSchedulingConstraintsResponse.ViolatingClass\x12L\n\x07modules\x18\x04 \x03(\x0b\x32;.bess.pb.CheckSchedulingConstraintsResponse.ViolatingModule\x1a`\n\x0eViolatingClass\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nconstraint\x18\x02 \x01(\x05\x12\x15\n\rassigned_node\x18\x03 \x01(\x05\x12\x15\n\rassigned_core\x18\x04 \x01(\x05\x1a\x1f\n\x0fViolatingModule\x12\x0c\n\x04name\x18\x01 \x01(\t\"4\n\x0c\x41\x64\x64TcRequest\x12$\n\x05\x63lass\x18\x01 \x01(\x0b\x32\x15.bess.pb.TrafficClass\"=\n\x15UpdateTcParamsRequest\x12$\n\x05\x63lass\x18\x01 \x01(\x0b\x32\x15.bess.pb.TrafficClass\"=\n\x15UpdateTcParentRequest\x12$\n\x05\x63lass\x18\x01 \x01(\x0b\x32\x15.bess.pb.TrafficClass\"!\n\x11GetTcStatsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x84\x01\n\x12GetTcStatsResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\x12\x0e\n\x06\x63ycles\x18\x04 \x01(\x04\x12\x0f\n\x07packets\x18\x05 \x01(\x04\x12\x0c\n\x04\x62its\x18\x06 \x01(\x04\"J\n\x13ListDriversResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x14\n\x0c\x64river_names\x18\x02 \x03(\t\"+\n\x14GetDriverInfoRequest\x12\x13\n\x0b\x64river_name\x18\x01 \x01(\t\"d\n\x15GetDriverInfoResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04help\x18\x03 \x01(\t\x12\x10\n\x08\x63ommands\x18\x04 \x03(\t\"\x93\x02\n\x11ListPortsResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12.\n\x05ports\x18\x02 \x03(\x0b\x32\x1f.bess.pb.ListPortsResponse.Port\x1a\xae\x01\n\x04Port\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x64river\x18\x02 \x01(\t\x12\x10\n\x08mac_addr\x18\x03 \x01(\t\x12\x11\n\tnum_inc_q\x18\x04 \x01(\x04\x12\x11\n\tnum_out_q\x18\x05 \x01(\x04\x12\x12\n\nsize_inc_q\x18\x06 \x01(\x04\x12\x12\n\nsize_out_q\x18\x07 \x01(\x04\x12(\n\ndriver_arg\x18\x08 \x01(\x0b\x32\x14.google.protobuf.Any\"\xa2\x01\n\x11\x43reatePortRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x64river\x18\x02 \x01(\t\x12\x11\n\tnum_inc_q\x18\x03 \x01(\x04\x12\x11\n\tnum_out_q\x18\x04 \x01(\x04\x12\x12\n\nsize_inc_q\x18\x05 \x01(\x04\x12\x12\n\nsize_out_q\x18\x06 \x01(\x04\x12!\n\x03\x61rg\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\";\n\x08PortConf\x12\x10\n\x08mac_addr\x18\x01 \x01(\t\x12\x0b\n\x03mtu\x18\x02 \x01(\r\x12\x10\n\x08\x61\x64min_up\x18\x03 \x01(\x08\"C\n\x12SetPortConfRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1f\n\x04\x63onf\x18\x02 \x01(\x0b\x32\x11.bess.pb.PortConf\"\"\n\x12GetPortConfRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"U\n\x13GetPortConfResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x1f\n\x04\x63onf\x18\x02 \x01(\x0b\x32\x11.bess.pb.PortConf\"S\n\x12\x43reatePortResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08mac_addr\x18\x03 \x01(\t\"\"\n\x12\x44\x65stroyPortRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"#\n\x13GetPortStatsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa3\x02\n\x14GetPortStatsResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12/\n\x03inc\x18\x02 \x01(\x0b\x32\".bess.pb.GetPortStatsResponse.Stat\x12/\n\x03out\x18\x03 \x01(\x0b\x32\".bess.pb.GetPortStatsResponse.Stat\x12\x11\n\ttimestamp\x18\x04 \x01(\x01\x1aw\n\x04Stat\x12\x0f\n\x07packets\x18\x01 \x01(\x04\x12\x0f\n\x07\x64ropped\x18\x02 \x01(\x04\x12\r\n\x05\x62ytes\x18\x03 \x01(\x04\x12\x16\n\x0erequested_hist\x18\x04 \x03(\x04\x12\x13\n\x0b\x61\x63tual_hist\x18\x05 \x03(\x04\x12\x11\n\tdiff_hist\x18\x06 \x03(\x04\"$\n\x14GetLinkStatusRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"|\n\x15GetLinkStatusResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\r\n\x05speed\x18\x02 \x01(\r\x12\x13\n\x0b\x66ull_duplex\x18\x03 \x01(\x08\x12\x0f\n\x07\x61utoneg\x18\x04 \x01(\x08\x12\x0f\n\x07link_up\x18\x05 \x01(\x08\"B\n\x12ListMclassResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\r\n\x05names\x18\x02 \x03(\t\"$\n\x14GetMclassInfoRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"r\n\x15GetMclassInfoResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04help\x18\x03 \x01(\t\x12\x0c\n\x04\x63mds\x18\x04 \x03(\t\x12\x10\n\x08\x63md_args\x18\x05 \x03(\t\"\xa0\x01\n\x13ListModulesResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x34\n\x07modules\x18\x02 \x03(\x0b\x32#.bess.pb.ListModulesResponse.Module\x1a\x34\n\x06Module\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06mclass\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\"V\n\x13\x43reateModuleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06mclass\x18\x02 \x01(\t\x12!\n\x03\x61rg\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"C\n\x14\x43reateModuleResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x0c\n\x04name\x18\x02 \x01(\t\"$\n\x14\x44\x65stroyModuleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"$\n\x14GetModuleInfoRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc5\x06\n\x15GetModuleInfoResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06mclass\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x34\n\x06igates\x18\x06 \x03(\x0b\x32$.bess.pb.GetModuleInfoResponse.IGate\x12\x34\n\x06ogates\x18\x07 \x03(\x0b\x32$.bess.pb.GetModuleInfoResponse.OGate\x12:\n\x08metadata\x18\x08 \x03(\x0b\x32(.bess.pb.GetModuleInfoResponse.Attribute\x12\x10\n\x08\x64\x65\x61\x64\x65nds\x18\t \x01(\x04\x1a\x31\n\x08GateHook\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x11\n\thook_name\x18\x02 \x01(\t\x1a\xf7\x01\n\x05IGate\x12\r\n\x05igate\x18\x01 \x01(\x04\x12:\n\x06ogates\x18\x02 \x03(\x0b\x32*.bess.pb.GetModuleInfoResponse.IGate.OGate\x12\x0b\n\x03\x63nt\x18\x03 \x01(\x04\x12\x0c\n\x04pkts\x18\x04 \x01(\x04\x12\r\n\x05\x62ytes\x18\x05 \x01(\x04\x12\x11\n\ttimestamp\x18\x06 \x01(\x01\x12:\n\tgatehooks\x18\x08 \x03(\x0b\x32\'.bess.pb.GetModuleInfoResponse.GateHook\x1a$\n\x05OGate\x12\r\n\x05ogate\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\tJ\x04\x08\x07\x10\x08\x1a\xb2\x01\n\x05OGate\x12\r\n\x05ogate\x18\x01 \x01(\x04\x12\x0b\n\x03\x63nt\x18\x02 \x01(\x04\x12\x0c\n\x04pkts\x18\x03 \x01(\x04\x12\r\n\x05\x62ytes\x18\x04 \x01(\x04\x12\x11\n\ttimestamp\x18\x05 \x01(\x01\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\r\n\x05igate\x18\x07 \x01(\x04\x12:\n\tgatehooks\x18\t \x03(\x0b\x32\'.bess.pb.GetModuleInfoResponse.GateHookJ\x04\x08\x08\x10\t\x1a\x45\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\x04 \x01(\x03\"i\n\x15\x43onnectModulesRequest\x12\n\n\x02m1\x18\x01 \x01(\t\x12\n\n\x02m2\x18\x02 \x01(\t\x12\r\n\x05ogate\x18\x03 \x01(\x04\x12\r\n\x05igate\x18\x04 \x01(\x04\x12\x1a\n\x12skip_default_hooks\x18\x05 \x01(\x08\"7\n\x18\x44isconnectModulesRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05ogate\x18\x02 \x01(\x04\"\x84\x02\n\x0bMempoolDump\x12\x0e\n\x06socket\x18\x01 \x01(\x05\x12\x13\n\x0binitialized\x18\x02 \x01(\x08\x12\x0f\n\x07mp_size\x18\x03 \x01(\r\x12\x15\n\rmp_cache_size\x18\x04 \x01(\r\x12\x17\n\x0fmp_element_size\x18\x05 \x01(\r\x12\x19\n\x11mp_populated_size\x18\x06 \x01(\r\x12\x1a\n\x12mp_available_count\x18\x07 \x01(\r\x12\x17\n\x0fmp_in_use_count\x18\x08 \x01(\r\x12\x12\n\nring_count\x18\t \x01(\r\x12\x17\n\x0fring_free_count\x18\n \x01(\r\x12\x12\n\nring_bytes\x18\x0b \x01(\x04\"$\n\x12\x44umpMempoolRequest\x12\x0e\n\x06socket\x18\x01 \x01(\x05\"Y\n\x13\x44umpMempoolResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12#\n\x05\x64umps\x18\x02 \x03(\x0b\x32\x14.bess.pb.MempoolDump\"N\n\x0e\x43ommandRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x01(\t\x12!\n\x03\x61rg\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"T\n\x0f\x43ommandResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"I\n\x19ListGateHookClassResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\r\n\x05names\x18\x02 \x03(\t\"+\n\x1bGetGateHookClassInfoRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"y\n\x1cGetGateHookClassInfoResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04help\x18\x03 \x01(\t\x12\x0c\n\x04\x63mds\x18\x04 \x03(\t\x12\x10\n\x08\x63md_args\x18\x05 \x03(\t\"\x18\n\x08TrackArg\x12\x0c\n\x04\x62its\x18\x05 \x01(\x08\"<\n\nTcpdumpArg\x12\x0c\n\x04\x66ifo\x18\x05 \x01(\t\x12\r\n\x05\x64\x65\x66\x65r\x18\x06 \x01(\x08\x12\x11\n\treconnect\x18\x07 \x01(\x08\";\n\tPcapngArg\x12\x0c\n\x04\x66ifo\x18\x05 \x01(\t\x12\r\n\x05\x64\x65\x66\x65r\x18\x06 \x01(\x08\x12\x11\n\treconnect\x18\x07 \x01(\x08\"\x97\x01\n\x0cGateHookInfo\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x11\n\thook_name\x18\x02 \x01(\t\x12\x13\n\x0bmodule_name\x18\x03 \x01(\t\x12\x0f\n\x05igate\x18\x04 \x01(\x03H\x00\x12\x0f\n\x05ogate\x18\x05 \x01(\x03H\x00\x12!\n\x03\x61rg\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyB\x06\n\x04gate\"O\n\x18\x43onfigureGateHookRequest\x12#\n\x04hook\x18\x01 \x01(\x0b\x32\x15.bess.pb.GateHookInfo\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\"H\n\x19\x43onfigureGateHookResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12\x0c\n\x04name\x18\x02 \x01(\t\"\\\n\x15ListGateHooksResponse\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0e.bess.pb.Error\x12$\n\x05hooks\x18\x02 \x03(\x0b\x32\x15.bess.pb.GateHookInfo\"J\n\x16GateHookCommandRequest\x12#\n\x04hook\x18\x01 \x01(\x0b\x32\x15.bess.pb.GateHookInfo\x12\x0b\n\x03\x63md\x18\x02 \x01(\t\"b\n\x1a\x43onfigureResumeHookRequest\x12\x11\n\thook_name\x18\x01 \x01(\t\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12!\n\x03\x61rg\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"!\n\x12PauseWorkerRequest\x12\x0b\n\x03wid\x18\x01 \x01(\x03\"\"\n\x13ResumeWorkerRequest\x12\x0b\n\x03wid\x18\x01 \x01(\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,error__pb2.DESCRIPTOR,])




_EMPTYREQUEST = _descriptor.Descriptor(
  name='EmptyRequest',
  full_name='bess.pb.EmptyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=81,
)


_EMPTYRESPONSE = _descriptor.Descriptor(
  name='EmptyResponse',
  full_name='bess.pb.EmptyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.EmptyResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=129,
)


_VERSIONRESPONSE = _descriptor.Descriptor(
  name='VersionResponse',
  full_name='bess.pb.VersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.VersionResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='bess.pb.VersionResponse.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=196,
)


_IMPORTPLUGINREQUEST = _descriptor.Descriptor(
  name='ImportPluginRequest',
  full_name='bess.pb.ImportPluginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='bess.pb.ImportPluginRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=233,
)


_UNLOADPLUGINREQUEST = _descriptor.Descriptor(
  name='UnloadPluginRequest',
  full_name='bess.pb.UnloadPluginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='bess.pb.UnloadPluginRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=270,
)


_LISTPLUGINSRESPONSE = _descriptor.Descriptor(
  name='ListPluginsResponse',
  full_name='bess.pb.ListPluginsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ListPluginsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paths', full_name='bess.pb.ListPluginsResponse.paths', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=339,
)


_LISTWORKERSRESPONSE_WORKERSTATUS = _descriptor.Descriptor(
  name='WorkerStatus',
  full_name='bess.pb.ListWorkersResponse.WorkerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wid', full_name='bess.pb.ListWorkersResponse.WorkerStatus.wid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='core', full_name='bess.pb.ListWorkersResponse.WorkerStatus.core', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='running', full_name='bess.pb.ListWorkersResponse.WorkerStatus.running', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_tcs', full_name='bess.pb.ListWorkersResponse.WorkerStatus.num_tcs', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='silent_drops', full_name='bess.pb.ListWorkersResponse.WorkerStatus.silent_drops', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=560,
)

_LISTWORKERSRESPONSE = _descriptor.Descriptor(
  name='ListWorkersResponse',
  full_name='bess.pb.ListWorkersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ListWorkersResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workers_status', full_name='bess.pb.ListWorkersResponse.workers_status', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTWORKERSRESPONSE_WORKERSTATUS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=560,
)


_ADDWORKERREQUEST = _descriptor.Descriptor(
  name='AddWorkerRequest',
  full_name='bess.pb.AddWorkerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wid', full_name='bess.pb.AddWorkerRequest.wid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='core', full_name='bess.pb.AddWorkerRequest.core', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduler', full_name='bess.pb.AddWorkerRequest.scheduler', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=626,
)


_DESTROYWORKERREQUEST = _descriptor.Descriptor(
  name='DestroyWorkerRequest',
  full_name='bess.pb.DestroyWorkerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wid', full_name='bess.pb.DestroyWorkerRequest.wid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=663,
)


_TRAFFICCLASS_LIMITENTRY = _descriptor.Descriptor(
  name='LimitEntry',
  full_name='bess.pb.TrafficClass.LimitEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bess.pb.TrafficClass.LimitEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bess.pb.TrafficClass.LimitEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1016,
)

_TRAFFICCLASS_MAXBURSTENTRY = _descriptor.Descriptor(
  name='MaxBurstEntry',
  full_name='bess.pb.TrafficClass.MaxBurstEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bess.pb.TrafficClass.MaxBurstEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bess.pb.TrafficClass.MaxBurstEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1065,
)

_TRAFFICCLASS = _descriptor.Descriptor(
  name='TrafficClass',
  full_name='bess.pb.TrafficClass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='bess.pb.TrafficClass.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.TrafficClass.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blocked', full_name='bess.pb.TrafficClass.blocked', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy', full_name='bess.pb.TrafficClass.policy', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource', full_name='bess.pb.TrafficClass.resource', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priority', full_name='bess.pb.TrafficClass.priority', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='share', full_name='bess.pb.TrafficClass.share', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wid', full_name='bess.pb.TrafficClass.wid', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='bess.pb.TrafficClass.limit', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_burst', full_name='bess.pb.TrafficClass.max_burst', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaf_module_name', full_name='bess.pb.TrafficClass.leaf_module_name', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaf_module_taskid', full_name='bess.pb.TrafficClass.leaf_module_taskid', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRAFFICCLASS_LIMITENTRY, _TRAFFICCLASS_MAXBURSTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='arg', full_name='bess.pb.TrafficClass.arg',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=666,
  serialized_end=1072,
)


_LISTTCSREQUEST = _descriptor.Descriptor(
  name='ListTcsRequest',
  full_name='bess.pb.ListTcsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wid', full_name='bess.pb.ListTcsRequest.wid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1074,
  serialized_end=1103,
)


_LISTTCSRESPONSE_TRAFFICCLASSSTATUS = _descriptor.Descriptor(
  name='TrafficClassStatus',
  full_name='bess.pb.ListTcsResponse.TrafficClassStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='class', full_name='bess.pb.ListTcsResponse.TrafficClassStatus.class', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='bess.pb.ListTcsResponse.TrafficClassStatus.parent', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1225,
  serialized_end=1299,
)

_LISTTCSRESPONSE = _descriptor.Descriptor(
  name='ListTcsResponse',
  full_name='bess.pb.ListTcsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ListTcsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classes_status', full_name='bess.pb.ListTcsResponse.classes_status', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTTCSRESPONSE_TRAFFICCLASSSTATUS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1299,
)


_CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGCLASS = _descriptor.Descriptor(
  name='ViolatingClass',
  full_name='bess.pb.CheckSchedulingConstraintsResponse.ViolatingClass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.CheckSchedulingConstraintsResponse.ViolatingClass.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constraint', full_name='bess.pb.CheckSchedulingConstraintsResponse.ViolatingClass.constraint', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assigned_node', full_name='bess.pb.CheckSchedulingConstraintsResponse.ViolatingClass.assigned_node', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assigned_core', full_name='bess.pb.CheckSchedulingConstraintsResponse.ViolatingClass.assigned_core', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1544,
  serialized_end=1640,
)

_CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGMODULE = _descriptor.Descriptor(
  name='ViolatingModule',
  full_name='bess.pb.CheckSchedulingConstraintsResponse.ViolatingModule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.CheckSchedulingConstraintsResponse.ViolatingModule.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1642,
  serialized_end=1673,
)

_CHECKSCHEDULINGCONSTRAINTSRESPONSE = _descriptor.Descriptor(
  name='CheckSchedulingConstraintsResponse',
  full_name='bess.pb.CheckSchedulingConstraintsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.CheckSchedulingConstraintsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fatal', full_name='bess.pb.CheckSchedulingConstraintsResponse.fatal', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='violations', full_name='bess.pb.CheckSchedulingConstraintsResponse.violations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modules', full_name='bess.pb.CheckSchedulingConstraintsResponse.modules', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGCLASS, _CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGMODULE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1302,
  serialized_end=1673,
)


_ADDTCREQUEST = _descriptor.Descriptor(
  name='AddTcRequest',
  full_name='bess.pb.AddTcRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='class', full_name='bess.pb.AddTcRequest.class', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1675,
  serialized_end=1727,
)


_UPDATETCPARAMSREQUEST = _descriptor.Descriptor(
  name='UpdateTcParamsRequest',
  full_name='bess.pb.UpdateTcParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='class', full_name='bess.pb.UpdateTcParamsRequest.class', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1729,
  serialized_end=1790,
)


_UPDATETCPARENTREQUEST = _descriptor.Descriptor(
  name='UpdateTcParentRequest',
  full_name='bess.pb.UpdateTcParentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='class', full_name='bess.pb.UpdateTcParentRequest.class', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1792,
  serialized_end=1853,
)


_GETTCSTATSREQUEST = _descriptor.Descriptor(
  name='GetTcStatsRequest',
  full_name='bess.pb.GetTcStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetTcStatsRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1855,
  serialized_end=1888,
)


_GETTCSTATSRESPONSE = _descriptor.Descriptor(
  name='GetTcStatsResponse',
  full_name='bess.pb.GetTcStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.GetTcStatsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='bess.pb.GetTcStatsResponse.timestamp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='bess.pb.GetTcStatsResponse.count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cycles', full_name='bess.pb.GetTcStatsResponse.cycles', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packets', full_name='bess.pb.GetTcStatsResponse.packets', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bits', full_name='bess.pb.GetTcStatsResponse.bits', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1891,
  serialized_end=2023,
)


_LISTDRIVERSRESPONSE = _descriptor.Descriptor(
  name='ListDriversResponse',
  full_name='bess.pb.ListDriversResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ListDriversResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='driver_names', full_name='bess.pb.ListDriversResponse.driver_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2099,
)


_GETDRIVERINFOREQUEST = _descriptor.Descriptor(
  name='GetDriverInfoRequest',
  full_name='bess.pb.GetDriverInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='driver_name', full_name='bess.pb.GetDriverInfoRequest.driver_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2101,
  serialized_end=2144,
)


_GETDRIVERINFORESPONSE = _descriptor.Descriptor(
  name='GetDriverInfoResponse',
  full_name='bess.pb.GetDriverInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.GetDriverInfoResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetDriverInfoResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='help', full_name='bess.pb.GetDriverInfoResponse.help', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commands', full_name='bess.pb.GetDriverInfoResponse.commands', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2146,
  serialized_end=2246,
)


_LISTPORTSRESPONSE_PORT = _descriptor.Descriptor(
  name='Port',
  full_name='bess.pb.ListPortsResponse.Port',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.ListPortsResponse.Port.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='driver', full_name='bess.pb.ListPortsResponse.Port.driver', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mac_addr', full_name='bess.pb.ListPortsResponse.Port.mac_addr', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_inc_q', full_name='bess.pb.ListPortsResponse.Port.num_inc_q', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_out_q', full_name='bess.pb.ListPortsResponse.Port.num_out_q', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_inc_q', full_name='bess.pb.ListPortsResponse.Port.size_inc_q', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_out_q', full_name='bess.pb.ListPortsResponse.Port.size_out_q', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='driver_arg', full_name='bess.pb.ListPortsResponse.Port.driver_arg', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2350,
  serialized_end=2524,
)

_LISTPORTSRESPONSE = _descriptor.Descriptor(
  name='ListPortsResponse',
  full_name='bess.pb.ListPortsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ListPortsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ports', full_name='bess.pb.ListPortsResponse.ports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTPORTSRESPONSE_PORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2249,
  serialized_end=2524,
)


_CREATEPORTREQUEST = _descriptor.Descriptor(
  name='CreatePortRequest',
  full_name='bess.pb.CreatePortRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.CreatePortRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='driver', full_name='bess.pb.CreatePortRequest.driver', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_inc_q', full_name='bess.pb.CreatePortRequest.num_inc_q', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_out_q', full_name='bess.pb.CreatePortRequest.num_out_q', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_inc_q', full_name='bess.pb.CreatePortRequest.size_inc_q', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_out_q', full_name='bess.pb.CreatePortRequest.size_out_q', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg', full_name='bess.pb.CreatePortRequest.arg', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2527,
  serialized_end=2689,
)


_PORTCONF = _descriptor.Descriptor(
  name='PortConf',
  full_name='bess.pb.PortConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mac_addr', full_name='bess.pb.PortConf.mac_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mtu', full_name='bess.pb.PortConf.mtu', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='admin_up', full_name='bess.pb.PortConf.admin_up', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2691,
  serialized_end=2750,
)


_SETPORTCONFREQUEST = _descriptor.Descriptor(
  name='SetPortConfRequest',
  full_name='bess.pb.SetPortConfRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.SetPortConfRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conf', full_name='bess.pb.SetPortConfRequest.conf', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2752,
  serialized_end=2819,
)


_GETPORTCONFREQUEST = _descriptor.Descriptor(
  name='GetPortConfRequest',
  full_name='bess.pb.GetPortConfRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetPortConfRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2821,
  serialized_end=2855,
)


_GETPORTCONFRESPONSE = _descriptor.Descriptor(
  name='GetPortConfResponse',
  full_name='bess.pb.GetPortConfResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.GetPortConfResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conf', full_name='bess.pb.GetPortConfResponse.conf', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2857,
  serialized_end=2942,
)


_CREATEPORTRESPONSE = _descriptor.Descriptor(
  name='CreatePortResponse',
  full_name='bess.pb.CreatePortResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.CreatePortResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.CreatePortResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mac_addr', full_name='bess.pb.CreatePortResponse.mac_addr', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2944,
  serialized_end=3027,
)


_DESTROYPORTREQUEST = _descriptor.Descriptor(
  name='DestroyPortRequest',
  full_name='bess.pb.DestroyPortRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.DestroyPortRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3029,
  serialized_end=3063,
)


_GETPORTSTATSREQUEST = _descriptor.Descriptor(
  name='GetPortStatsRequest',
  full_name='bess.pb.GetPortStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetPortStatsRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3065,
  serialized_end=3100,
)


_GETPORTSTATSRESPONSE_STAT = _descriptor.Descriptor(
  name='Stat',
  full_name='bess.pb.GetPortStatsResponse.Stat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packets', full_name='bess.pb.GetPortStatsResponse.Stat.packets', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dropped', full_name='bess.pb.GetPortStatsResponse.Stat.dropped', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='bess.pb.GetPortStatsResponse.Stat.bytes', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requested_hist', full_name='bess.pb.GetPortStatsResponse.Stat.requested_hist', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actual_hist', full_name='bess.pb.GetPortStatsResponse.Stat.actual_hist', index=4,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='diff_hist', full_name='bess.pb.GetPortStatsResponse.Stat.diff_hist', index=5,
      number=6, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3275,
  serialized_end=3394,
)

_GETPORTSTATSRESPONSE = _descriptor.Descriptor(
  name='GetPortStatsResponse',
  full_name='bess.pb.GetPortStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.GetPortStatsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inc', full_name='bess.pb.GetPortStatsResponse.inc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out', full_name='bess.pb.GetPortStatsResponse.out', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='bess.pb.GetPortStatsResponse.timestamp', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETPORTSTATSRESPONSE_STAT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3103,
  serialized_end=3394,
)


_GETLINKSTATUSREQUEST = _descriptor.Descriptor(
  name='GetLinkStatusRequest',
  full_name='bess.pb.GetLinkStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetLinkStatusRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3396,
  serialized_end=3432,
)


_GETLINKSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetLinkStatusResponse',
  full_name='bess.pb.GetLinkStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.GetLinkStatusResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='bess.pb.GetLinkStatusResponse.speed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_duplex', full_name='bess.pb.GetLinkStatusResponse.full_duplex', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='autoneg', full_name='bess.pb.GetLinkStatusResponse.autoneg', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link_up', full_name='bess.pb.GetLinkStatusResponse.link_up', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3434,
  serialized_end=3558,
)


_LISTMCLASSRESPONSE = _descriptor.Descriptor(
  name='ListMclassResponse',
  full_name='bess.pb.ListMclassResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ListMclassResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names', full_name='bess.pb.ListMclassResponse.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3560,
  serialized_end=3626,
)


_GETMCLASSINFOREQUEST = _descriptor.Descriptor(
  name='GetMclassInfoRequest',
  full_name='bess.pb.GetMclassInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetMclassInfoRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3628,
  serialized_end=3664,
)


_GETMCLASSINFORESPONSE = _descriptor.Descriptor(
  name='GetMclassInfoResponse',
  full_name='bess.pb.GetMclassInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.GetMclassInfoResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetMclassInfoResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='help', full_name='bess.pb.GetMclassInfoResponse.help', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmds', full_name='bess.pb.GetMclassInfoResponse.cmds', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmd_args', full_name='bess.pb.GetMclassInfoResponse.cmd_args', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3666,
  serialized_end=3780,
)


_LISTMODULESRESPONSE_MODULE = _descriptor.Descriptor(
  name='Module',
  full_name='bess.pb.ListModulesResponse.Module',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.ListModulesResponse.Module.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mclass', full_name='bess.pb.ListModulesResponse.Module.mclass', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desc', full_name='bess.pb.ListModulesResponse.Module.desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3891,
  serialized_end=3943,
)

_LISTMODULESRESPONSE = _descriptor.Descriptor(
  name='ListModulesResponse',
  full_name='bess.pb.ListModulesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ListModulesResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modules', full_name='bess.pb.ListModulesResponse.modules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTMODULESRESPONSE_MODULE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3783,
  serialized_end=3943,
)


_CREATEMODULEREQUEST = _descriptor.Descriptor(
  name='CreateModuleRequest',
  full_name='bess.pb.CreateModuleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.CreateModuleRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mclass', full_name='bess.pb.CreateModuleRequest.mclass', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg', full_name='bess.pb.CreateModuleRequest.arg', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3945,
  serialized_end=4031,
)


_CREATEMODULERESPONSE = _descriptor.Descriptor(
  name='CreateModuleResponse',
  full_name='bess.pb.CreateModuleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.CreateModuleResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.CreateModuleResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4033,
  serialized_end=4100,
)


_DESTROYMODULEREQUEST = _descriptor.Descriptor(
  name='DestroyModuleRequest',
  full_name='bess.pb.DestroyModuleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.DestroyModuleRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4102,
  serialized_end=4138,
)


_GETMODULEINFOREQUEST = _descriptor.Descriptor(
  name='GetModuleInfoRequest',
  full_name='bess.pb.GetModuleInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetModuleInfoRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4140,
  serialized_end=4176,
)


_GETMODULEINFORESPONSE_GATEHOOK = _descriptor.Descriptor(
  name='GateHook',
  full_name='bess.pb.GetModuleInfoResponse.GateHook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='bess.pb.GetModuleInfoResponse.GateHook.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hook_name', full_name='bess.pb.GetModuleInfoResponse.GateHook.hook_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4465,
  serialized_end=4514,
)

_GETMODULEINFORESPONSE_IGATE_OGATE = _descriptor.Descriptor(
  name='OGate',
  full_name='bess.pb.GetModuleInfoResponse.IGate.OGate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ogate', full_name='bess.pb.GetModuleInfoResponse.IGate.OGate.ogate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetModuleInfoResponse.IGate.OGate.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4722,
  serialized_end=4758,
)

_GETMODULEINFORESPONSE_IGATE = _descriptor.Descriptor(
  name='IGate',
  full_name='bess.pb.GetModuleInfoResponse.IGate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='igate', full_name='bess.pb.GetModuleInfoResponse.IGate.igate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ogates', full_name='bess.pb.GetModuleInfoResponse.IGate.ogates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cnt', full_name='bess.pb.GetModuleInfoResponse.IGate.cnt', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkts', full_name='bess.pb.GetModuleInfoResponse.IGate.pkts', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='bess.pb.GetModuleInfoResponse.IGate.bytes', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='bess.pb.GetModuleInfoResponse.IGate.timestamp', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatehooks', full_name='bess.pb.GetModuleInfoResponse.IGate.gatehooks', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETMODULEINFORESPONSE_IGATE_OGATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4517,
  serialized_end=4764,
)

_GETMODULEINFORESPONSE_OGATE = _descriptor.Descriptor(
  name='OGate',
  full_name='bess.pb.GetModuleInfoResponse.OGate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ogate', full_name='bess.pb.GetModuleInfoResponse.OGate.ogate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cnt', full_name='bess.pb.GetModuleInfoResponse.OGate.cnt', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkts', full_name='bess.pb.GetModuleInfoResponse.OGate.pkts', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='bess.pb.GetModuleInfoResponse.OGate.bytes', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='bess.pb.GetModuleInfoResponse.OGate.timestamp', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetModuleInfoResponse.OGate.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='igate', full_name='bess.pb.GetModuleInfoResponse.OGate.igate', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatehooks', full_name='bess.pb.GetModuleInfoResponse.OGate.gatehooks', index=7,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4767,
  serialized_end=4945,
)

_GETMODULEINFORESPONSE_ATTRIBUTE = _descriptor.Descriptor(
  name='Attribute',
  full_name='bess.pb.GetModuleInfoResponse.Attribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetModuleInfoResponse.Attribute.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.GetModuleInfoResponse.Attribute.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='bess.pb.GetModuleInfoResponse.Attribute.mode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='bess.pb.GetModuleInfoResponse.Attribute.offset', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4947,
  serialized_end=5016,
)

_GETMODULEINFORESPONSE = _descriptor.Descriptor(
  name='GetModuleInfoResponse',
  full_name='bess.pb.GetModuleInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.GetModuleInfoResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetModuleInfoResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mclass', full_name='bess.pb.GetModuleInfoResponse.mclass', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desc', full_name='bess.pb.GetModuleInfoResponse.desc', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='igates', full_name='bess.pb.GetModuleInfoResponse.igates', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ogates', full_name='bess.pb.GetModuleInfoResponse.ogates', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='bess.pb.GetModuleInfoResponse.metadata', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deadends', full_name='bess.pb.GetModuleInfoResponse.deadends', index=7,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETMODULEINFORESPONSE_GATEHOOK, _GETMODULEINFORESPONSE_IGATE, _GETMODULEINFORESPONSE_OGATE, _GETMODULEINFORESPONSE_ATTRIBUTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4179,
  serialized_end=5016,
)


_CONNECTMODULESREQUEST = _descriptor.Descriptor(
  name='ConnectModulesRequest',
  full_name='bess.pb.ConnectModulesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='m1', full_name='bess.pb.ConnectModulesRequest.m1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='m2', full_name='bess.pb.ConnectModulesRequest.m2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ogate', full_name='bess.pb.ConnectModulesRequest.ogate', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='igate', full_name='bess.pb.ConnectModulesRequest.igate', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skip_default_hooks', full_name='bess.pb.ConnectModulesRequest.skip_default_hooks', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5018,
  serialized_end=5123,
)


_DISCONNECTMODULESREQUEST = _descriptor.Descriptor(
  name='DisconnectModulesRequest',
  full_name='bess.pb.DisconnectModulesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.DisconnectModulesRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ogate', full_name='bess.pb.DisconnectModulesRequest.ogate', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5125,
  serialized_end=5180,
)


_MEMPOOLDUMP = _descriptor.Descriptor(
  name='MempoolDump',
  full_name='bess.pb.MempoolDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='bess.pb.MempoolDump.socket', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initialized', full_name='bess.pb.MempoolDump.initialized', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mp_size', full_name='bess.pb.MempoolDump.mp_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mp_cache_size', full_name='bess.pb.MempoolDump.mp_cache_size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mp_element_size', full_name='bess.pb.MempoolDump.mp_element_size', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mp_populated_size', full_name='bess.pb.MempoolDump.mp_populated_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mp_available_count', full_name='bess.pb.MempoolDump.mp_available_count', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mp_in_use_count', full_name='bess.pb.MempoolDump.mp_in_use_count', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ring_count', full_name='bess.pb.MempoolDump.ring_count', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ring_free_count', full_name='bess.pb.MempoolDump.ring_free_count', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ring_bytes', full_name='bess.pb.MempoolDump.ring_bytes', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5183,
  serialized_end=5443,
)


_DUMPMEMPOOLREQUEST = _descriptor.Descriptor(
  name='DumpMempoolRequest',
  full_name='bess.pb.DumpMempoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='bess.pb.DumpMempoolRequest.socket', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5445,
  serialized_end=5481,
)


_DUMPMEMPOOLRESPONSE = _descriptor.Descriptor(
  name='DumpMempoolResponse',
  full_name='bess.pb.DumpMempoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.DumpMempoolResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dumps', full_name='bess.pb.DumpMempoolResponse.dumps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5483,
  serialized_end=5572,
)


_COMMANDREQUEST = _descriptor.Descriptor(
  name='CommandRequest',
  full_name='bess.pb.CommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.CommandRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='bess.pb.CommandRequest.cmd', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg', full_name='bess.pb.CommandRequest.arg', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5574,
  serialized_end=5652,
)


_COMMANDRESPONSE = _descriptor.Descriptor(
  name='CommandResponse',
  full_name='bess.pb.CommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.CommandResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='bess.pb.CommandResponse.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5654,
  serialized_end=5738,
)


_LISTGATEHOOKCLASSRESPONSE = _descriptor.Descriptor(
  name='ListGateHookClassResponse',
  full_name='bess.pb.ListGateHookClassResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ListGateHookClassResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names', full_name='bess.pb.ListGateHookClassResponse.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5740,
  serialized_end=5813,
)


_GETGATEHOOKCLASSINFOREQUEST = _descriptor.Descriptor(
  name='GetGateHookClassInfoRequest',
  full_name='bess.pb.GetGateHookClassInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetGateHookClassInfoRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5815,
  serialized_end=5858,
)


_GETGATEHOOKCLASSINFORESPONSE = _descriptor.Descriptor(
  name='GetGateHookClassInfoResponse',
  full_name='bess.pb.GetGateHookClassInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.GetGateHookClassInfoResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.GetGateHookClassInfoResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='help', full_name='bess.pb.GetGateHookClassInfoResponse.help', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmds', full_name='bess.pb.GetGateHookClassInfoResponse.cmds', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmd_args', full_name='bess.pb.GetGateHookClassInfoResponse.cmd_args', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5860,
  serialized_end=5981,
)


_TRACKARG = _descriptor.Descriptor(
  name='TrackArg',
  full_name='bess.pb.TrackArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bits', full_name='bess.pb.TrackArg.bits', index=0,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5983,
  serialized_end=6007,
)


_TCPDUMPARG = _descriptor.Descriptor(
  name='TcpdumpArg',
  full_name='bess.pb.TcpdumpArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fifo', full_name='bess.pb.TcpdumpArg.fifo', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defer', full_name='bess.pb.TcpdumpArg.defer', index=1,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reconnect', full_name='bess.pb.TcpdumpArg.reconnect', index=2,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6009,
  serialized_end=6069,
)


_PCAPNGARG = _descriptor.Descriptor(
  name='PcapngArg',
  full_name='bess.pb.PcapngArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fifo', full_name='bess.pb.PcapngArg.fifo', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defer', full_name='bess.pb.PcapngArg.defer', index=1,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reconnect', full_name='bess.pb.PcapngArg.reconnect', index=2,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6071,
  serialized_end=6130,
)


_GATEHOOKINFO = _descriptor.Descriptor(
  name='GateHookInfo',
  full_name='bess.pb.GateHookInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='bess.pb.GateHookInfo.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hook_name', full_name='bess.pb.GateHookInfo.hook_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='module_name', full_name='bess.pb.GateHookInfo.module_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='igate', full_name='bess.pb.GateHookInfo.igate', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ogate', full_name='bess.pb.GateHookInfo.ogate', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg', full_name='bess.pb.GateHookInfo.arg', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='gate', full_name='bess.pb.GateHookInfo.gate',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=6133,
  serialized_end=6284,
)


_CONFIGUREGATEHOOKREQUEST = _descriptor.Descriptor(
  name='ConfigureGateHookRequest',
  full_name='bess.pb.ConfigureGateHookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hook', full_name='bess.pb.ConfigureGateHookRequest.hook', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable', full_name='bess.pb.ConfigureGateHookRequest.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6286,
  serialized_end=6365,
)


_CONFIGUREGATEHOOKRESPONSE = _descriptor.Descriptor(
  name='ConfigureGateHookResponse',
  full_name='bess.pb.ConfigureGateHookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ConfigureGateHookResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.ConfigureGateHookResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6367,
  serialized_end=6439,
)


_LISTGATEHOOKSRESPONSE = _descriptor.Descriptor(
  name='ListGateHooksResponse',
  full_name='bess.pb.ListGateHooksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='bess.pb.ListGateHooksResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hooks', full_name='bess.pb.ListGateHooksResponse.hooks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6441,
  serialized_end=6533,
)


_GATEHOOKCOMMANDREQUEST = _descriptor.Descriptor(
  name='GateHookCommandRequest',
  full_name='bess.pb.GateHookCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hook', full_name='bess.pb.GateHookCommandRequest.hook', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='bess.pb.GateHookCommandRequest.cmd', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6535,
  serialized_end=6609,
)


_CONFIGURERESUMEHOOKREQUEST = _descriptor.Descriptor(
  name='ConfigureResumeHookRequest',
  full_name='bess.pb.ConfigureResumeHookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hook_name', full_name='bess.pb.ConfigureResumeHookRequest.hook_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable', full_name='bess.pb.ConfigureResumeHookRequest.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg', full_name='bess.pb.ConfigureResumeHookRequest.arg', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6611,
  serialized_end=6709,
)


_PAUSEWORKERREQUEST = _descriptor.Descriptor(
  name='PauseWorkerRequest',
  full_name='bess.pb.PauseWorkerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wid', full_name='bess.pb.PauseWorkerRequest.wid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6711,
  serialized_end=6744,
)


_RESUMEWORKERREQUEST = _descriptor.Descriptor(
  name='ResumeWorkerRequest',
  full_name='bess.pb.ResumeWorkerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wid', full_name='bess.pb.ResumeWorkerRequest.wid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6746,
  serialized_end=6780,
)

_EMPTYRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_VERSIONRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTPLUGINSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTWORKERSRESPONSE_WORKERSTATUS.containing_type = _LISTWORKERSRESPONSE
_LISTWORKERSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTWORKERSRESPONSE.fields_by_name['workers_status'].message_type = _LISTWORKERSRESPONSE_WORKERSTATUS
_TRAFFICCLASS_LIMITENTRY.containing_type = _TRAFFICCLASS
_TRAFFICCLASS_MAXBURSTENTRY.containing_type = _TRAFFICCLASS
_TRAFFICCLASS.fields_by_name['limit'].message_type = _TRAFFICCLASS_LIMITENTRY
_TRAFFICCLASS.fields_by_name['max_burst'].message_type = _TRAFFICCLASS_MAXBURSTENTRY
_TRAFFICCLASS.oneofs_by_name['arg'].fields.append(
  _TRAFFICCLASS.fields_by_name['priority'])
_TRAFFICCLASS.fields_by_name['priority'].containing_oneof = _TRAFFICCLASS.oneofs_by_name['arg']
_TRAFFICCLASS.oneofs_by_name['arg'].fields.append(
  _TRAFFICCLASS.fields_by_name['share'])
_TRAFFICCLASS.fields_by_name['share'].containing_oneof = _TRAFFICCLASS.oneofs_by_name['arg']
_LISTTCSRESPONSE_TRAFFICCLASSSTATUS.fields_by_name['class'].message_type = _TRAFFICCLASS
_LISTTCSRESPONSE_TRAFFICCLASSSTATUS.containing_type = _LISTTCSRESPONSE
_LISTTCSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTTCSRESPONSE.fields_by_name['classes_status'].message_type = _LISTTCSRESPONSE_TRAFFICCLASSSTATUS
_CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGCLASS.containing_type = _CHECKSCHEDULINGCONSTRAINTSRESPONSE
_CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGMODULE.containing_type = _CHECKSCHEDULINGCONSTRAINTSRESPONSE
_CHECKSCHEDULINGCONSTRAINTSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_CHECKSCHEDULINGCONSTRAINTSRESPONSE.fields_by_name['violations'].message_type = _CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGCLASS
_CHECKSCHEDULINGCONSTRAINTSRESPONSE.fields_by_name['modules'].message_type = _CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGMODULE
_ADDTCREQUEST.fields_by_name['class'].message_type = _TRAFFICCLASS
_UPDATETCPARAMSREQUEST.fields_by_name['class'].message_type = _TRAFFICCLASS
_UPDATETCPARENTREQUEST.fields_by_name['class'].message_type = _TRAFFICCLASS
_GETTCSTATSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTDRIVERSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_GETDRIVERINFORESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTPORTSRESPONSE_PORT.fields_by_name['driver_arg'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LISTPORTSRESPONSE_PORT.containing_type = _LISTPORTSRESPONSE
_LISTPORTSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTPORTSRESPONSE.fields_by_name['ports'].message_type = _LISTPORTSRESPONSE_PORT
_CREATEPORTREQUEST.fields_by_name['arg'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SETPORTCONFREQUEST.fields_by_name['conf'].message_type = _PORTCONF
_GETPORTCONFRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_GETPORTCONFRESPONSE.fields_by_name['conf'].message_type = _PORTCONF
_CREATEPORTRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_GETPORTSTATSRESPONSE_STAT.containing_type = _GETPORTSTATSRESPONSE
_GETPORTSTATSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_GETPORTSTATSRESPONSE.fields_by_name['inc'].message_type = _GETPORTSTATSRESPONSE_STAT
_GETPORTSTATSRESPONSE.fields_by_name['out'].message_type = _GETPORTSTATSRESPONSE_STAT
_GETLINKSTATUSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTMCLASSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_GETMCLASSINFORESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTMODULESRESPONSE_MODULE.containing_type = _LISTMODULESRESPONSE
_LISTMODULESRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTMODULESRESPONSE.fields_by_name['modules'].message_type = _LISTMODULESRESPONSE_MODULE
_CREATEMODULEREQUEST.fields_by_name['arg'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CREATEMODULERESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_GETMODULEINFORESPONSE_GATEHOOK.containing_type = _GETMODULEINFORESPONSE
_GETMODULEINFORESPONSE_IGATE_OGATE.containing_type = _GETMODULEINFORESPONSE_IGATE
_GETMODULEINFORESPONSE_IGATE.fields_by_name['ogates'].message_type = _GETMODULEINFORESPONSE_IGATE_OGATE
_GETMODULEINFORESPONSE_IGATE.fields_by_name['gatehooks'].message_type = _GETMODULEINFORESPONSE_GATEHOOK
_GETMODULEINFORESPONSE_IGATE.containing_type = _GETMODULEINFORESPONSE
_GETMODULEINFORESPONSE_OGATE.fields_by_name['gatehooks'].message_type = _GETMODULEINFORESPONSE_GATEHOOK
_GETMODULEINFORESPONSE_OGATE.containing_type = _GETMODULEINFORESPONSE
_GETMODULEINFORESPONSE_ATTRIBUTE.containing_type = _GETMODULEINFORESPONSE
_GETMODULEINFORESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_GETMODULEINFORESPONSE.fields_by_name['igates'].message_type = _GETMODULEINFORESPONSE_IGATE
_GETMODULEINFORESPONSE.fields_by_name['ogates'].message_type = _GETMODULEINFORESPONSE_OGATE
_GETMODULEINFORESPONSE.fields_by_name['metadata'].message_type = _GETMODULEINFORESPONSE_ATTRIBUTE
_DUMPMEMPOOLRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_DUMPMEMPOOLRESPONSE.fields_by_name['dumps'].message_type = _MEMPOOLDUMP
_COMMANDREQUEST.fields_by_name['arg'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_COMMANDRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_COMMANDRESPONSE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LISTGATEHOOKCLASSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_GETGATEHOOKCLASSINFORESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_GATEHOOKINFO.fields_by_name['arg'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GATEHOOKINFO.oneofs_by_name['gate'].fields.append(
  _GATEHOOKINFO.fields_by_name['igate'])
_GATEHOOKINFO.fields_by_name['igate'].containing_oneof = _GATEHOOKINFO.oneofs_by_name['gate']
_GATEHOOKINFO.oneofs_by_name['gate'].fields.append(
  _GATEHOOKINFO.fields_by_name['ogate'])
_GATEHOOKINFO.fields_by_name['ogate'].containing_oneof = _GATEHOOKINFO.oneofs_by_name['gate']
_CONFIGUREGATEHOOKREQUEST.fields_by_name['hook'].message_type = _GATEHOOKINFO
_CONFIGUREGATEHOOKRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTGATEHOOKSRESPONSE.fields_by_name['error'].message_type = error__pb2._ERROR
_LISTGATEHOOKSRESPONSE.fields_by_name['hooks'].message_type = _GATEHOOKINFO
_GATEHOOKCOMMANDREQUEST.fields_by_name['hook'].message_type = _GATEHOOKINFO
_CONFIGURERESUMEHOOKREQUEST.fields_by_name['arg'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['EmptyRequest'] = _EMPTYREQUEST
DESCRIPTOR.message_types_by_name['EmptyResponse'] = _EMPTYRESPONSE
DESCRIPTOR.message_types_by_name['VersionResponse'] = _VERSIONRESPONSE
DESCRIPTOR.message_types_by_name['ImportPluginRequest'] = _IMPORTPLUGINREQUEST
DESCRIPTOR.message_types_by_name['UnloadPluginRequest'] = _UNLOADPLUGINREQUEST
DESCRIPTOR.message_types_by_name['ListPluginsResponse'] = _LISTPLUGINSRESPONSE
DESCRIPTOR.message_types_by_name['ListWorkersResponse'] = _LISTWORKERSRESPONSE
DESCRIPTOR.message_types_by_name['AddWorkerRequest'] = _ADDWORKERREQUEST
DESCRIPTOR.message_types_by_name['DestroyWorkerRequest'] = _DESTROYWORKERREQUEST
DESCRIPTOR.message_types_by_name['TrafficClass'] = _TRAFFICCLASS
DESCRIPTOR.message_types_by_name['ListTcsRequest'] = _LISTTCSREQUEST
DESCRIPTOR.message_types_by_name['ListTcsResponse'] = _LISTTCSRESPONSE
DESCRIPTOR.message_types_by_name['CheckSchedulingConstraintsResponse'] = _CHECKSCHEDULINGCONSTRAINTSRESPONSE
DESCRIPTOR.message_types_by_name['AddTcRequest'] = _ADDTCREQUEST
DESCRIPTOR.message_types_by_name['UpdateTcParamsRequest'] = _UPDATETCPARAMSREQUEST
DESCRIPTOR.message_types_by_name['UpdateTcParentRequest'] = _UPDATETCPARENTREQUEST
DESCRIPTOR.message_types_by_name['GetTcStatsRequest'] = _GETTCSTATSREQUEST
DESCRIPTOR.message_types_by_name['GetTcStatsResponse'] = _GETTCSTATSRESPONSE
DESCRIPTOR.message_types_by_name['ListDriversResponse'] = _LISTDRIVERSRESPONSE
DESCRIPTOR.message_types_by_name['GetDriverInfoRequest'] = _GETDRIVERINFOREQUEST
DESCRIPTOR.message_types_by_name['GetDriverInfoResponse'] = _GETDRIVERINFORESPONSE
DESCRIPTOR.message_types_by_name['ListPortsResponse'] = _LISTPORTSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePortRequest'] = _CREATEPORTREQUEST
DESCRIPTOR.message_types_by_name['PortConf'] = _PORTCONF
DESCRIPTOR.message_types_by_name['SetPortConfRequest'] = _SETPORTCONFREQUEST
DESCRIPTOR.message_types_by_name['GetPortConfRequest'] = _GETPORTCONFREQUEST
DESCRIPTOR.message_types_by_name['GetPortConfResponse'] = _GETPORTCONFRESPONSE
DESCRIPTOR.message_types_by_name['CreatePortResponse'] = _CREATEPORTRESPONSE
DESCRIPTOR.message_types_by_name['DestroyPortRequest'] = _DESTROYPORTREQUEST
DESCRIPTOR.message_types_by_name['GetPortStatsRequest'] = _GETPORTSTATSREQUEST
DESCRIPTOR.message_types_by_name['GetPortStatsResponse'] = _GETPORTSTATSRESPONSE
DESCRIPTOR.message_types_by_name['GetLinkStatusRequest'] = _GETLINKSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetLinkStatusResponse'] = _GETLINKSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['ListMclassResponse'] = _LISTMCLASSRESPONSE
DESCRIPTOR.message_types_by_name['GetMclassInfoRequest'] = _GETMCLASSINFOREQUEST
DESCRIPTOR.message_types_by_name['GetMclassInfoResponse'] = _GETMCLASSINFORESPONSE
DESCRIPTOR.message_types_by_name['ListModulesResponse'] = _LISTMODULESRESPONSE
DESCRIPTOR.message_types_by_name['CreateModuleRequest'] = _CREATEMODULEREQUEST
DESCRIPTOR.message_types_by_name['CreateModuleResponse'] = _CREATEMODULERESPONSE
DESCRIPTOR.message_types_by_name['DestroyModuleRequest'] = _DESTROYMODULEREQUEST
DESCRIPTOR.message_types_by_name['GetModuleInfoRequest'] = _GETMODULEINFOREQUEST
DESCRIPTOR.message_types_by_name['GetModuleInfoResponse'] = _GETMODULEINFORESPONSE
DESCRIPTOR.message_types_by_name['ConnectModulesRequest'] = _CONNECTMODULESREQUEST
DESCRIPTOR.message_types_by_name['DisconnectModulesRequest'] = _DISCONNECTMODULESREQUEST
DESCRIPTOR.message_types_by_name['MempoolDump'] = _MEMPOOLDUMP
DESCRIPTOR.message_types_by_name['DumpMempoolRequest'] = _DUMPMEMPOOLREQUEST
DESCRIPTOR.message_types_by_name['DumpMempoolResponse'] = _DUMPMEMPOOLRESPONSE
DESCRIPTOR.message_types_by_name['CommandRequest'] = _COMMANDREQUEST
DESCRIPTOR.message_types_by_name['CommandResponse'] = _COMMANDRESPONSE
DESCRIPTOR.message_types_by_name['ListGateHookClassResponse'] = _LISTGATEHOOKCLASSRESPONSE
DESCRIPTOR.message_types_by_name['GetGateHookClassInfoRequest'] = _GETGATEHOOKCLASSINFOREQUEST
DESCRIPTOR.message_types_by_name['GetGateHookClassInfoResponse'] = _GETGATEHOOKCLASSINFORESPONSE
DESCRIPTOR.message_types_by_name['TrackArg'] = _TRACKARG
DESCRIPTOR.message_types_by_name['TcpdumpArg'] = _TCPDUMPARG
DESCRIPTOR.message_types_by_name['PcapngArg'] = _PCAPNGARG
DESCRIPTOR.message_types_by_name['GateHookInfo'] = _GATEHOOKINFO
DESCRIPTOR.message_types_by_name['ConfigureGateHookRequest'] = _CONFIGUREGATEHOOKREQUEST
DESCRIPTOR.message_types_by_name['ConfigureGateHookResponse'] = _CONFIGUREGATEHOOKRESPONSE
DESCRIPTOR.message_types_by_name['ListGateHooksResponse'] = _LISTGATEHOOKSRESPONSE
DESCRIPTOR.message_types_by_name['GateHookCommandRequest'] = _GATEHOOKCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['ConfigureResumeHookRequest'] = _CONFIGURERESUMEHOOKREQUEST
DESCRIPTOR.message_types_by_name['PauseWorkerRequest'] = _PAUSEWORKERREQUEST
DESCRIPTOR.message_types_by_name['ResumeWorkerRequest'] = _RESUMEWORKERREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EmptyRequest = _reflection.GeneratedProtocolMessageType('EmptyRequest', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.EmptyRequest)
  })
_sym_db.RegisterMessage(EmptyRequest)

EmptyResponse = _reflection.GeneratedProtocolMessageType('EmptyResponse', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.EmptyResponse)
  })
_sym_db.RegisterMessage(EmptyResponse)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.VersionResponse)
  })
_sym_db.RegisterMessage(VersionResponse)

ImportPluginRequest = _reflection.GeneratedProtocolMessageType('ImportPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTPLUGINREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ImportPluginRequest)
  })
_sym_db.RegisterMessage(ImportPluginRequest)

UnloadPluginRequest = _reflection.GeneratedProtocolMessageType('UnloadPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNLOADPLUGINREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.UnloadPluginRequest)
  })
_sym_db.RegisterMessage(UnloadPluginRequest)

ListPluginsResponse = _reflection.GeneratedProtocolMessageType('ListPluginsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLUGINSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListPluginsResponse)
  })
_sym_db.RegisterMessage(ListPluginsResponse)

ListWorkersResponse = _reflection.GeneratedProtocolMessageType('ListWorkersResponse', (_message.Message,), {

  'WorkerStatus' : _reflection.GeneratedProtocolMessageType('WorkerStatus', (_message.Message,), {
    'DESCRIPTOR' : _LISTWORKERSRESPONSE_WORKERSTATUS,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.ListWorkersResponse.WorkerStatus)
    })
  ,
  'DESCRIPTOR' : _LISTWORKERSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListWorkersResponse)
  })
_sym_db.RegisterMessage(ListWorkersResponse)
_sym_db.RegisterMessage(ListWorkersResponse.WorkerStatus)

AddWorkerRequest = _reflection.GeneratedProtocolMessageType('AddWorkerRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDWORKERREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.AddWorkerRequest)
  })
_sym_db.RegisterMessage(AddWorkerRequest)

DestroyWorkerRequest = _reflection.GeneratedProtocolMessageType('DestroyWorkerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESTROYWORKERREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DestroyWorkerRequest)
  })
_sym_db.RegisterMessage(DestroyWorkerRequest)

TrafficClass = _reflection.GeneratedProtocolMessageType('TrafficClass', (_message.Message,), {

  'LimitEntry' : _reflection.GeneratedProtocolMessageType('LimitEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRAFFICCLASS_LIMITENTRY,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.TrafficClass.LimitEntry)
    })
  ,

  'MaxBurstEntry' : _reflection.GeneratedProtocolMessageType('MaxBurstEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRAFFICCLASS_MAXBURSTENTRY,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.TrafficClass.MaxBurstEntry)
    })
  ,
  'DESCRIPTOR' : _TRAFFICCLASS,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.TrafficClass)
  })
_sym_db.RegisterMessage(TrafficClass)
_sym_db.RegisterMessage(TrafficClass.LimitEntry)
_sym_db.RegisterMessage(TrafficClass.MaxBurstEntry)

ListTcsRequest = _reflection.GeneratedProtocolMessageType('ListTcsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTCSREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListTcsRequest)
  })
_sym_db.RegisterMessage(ListTcsRequest)

ListTcsResponse = _reflection.GeneratedProtocolMessageType('ListTcsResponse', (_message.Message,), {

  'TrafficClassStatus' : _reflection.GeneratedProtocolMessageType('TrafficClassStatus', (_message.Message,), {
    'DESCRIPTOR' : _LISTTCSRESPONSE_TRAFFICCLASSSTATUS,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.ListTcsResponse.TrafficClassStatus)
    })
  ,
  'DESCRIPTOR' : _LISTTCSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListTcsResponse)
  })
_sym_db.RegisterMessage(ListTcsResponse)
_sym_db.RegisterMessage(ListTcsResponse.TrafficClassStatus)

CheckSchedulingConstraintsResponse = _reflection.GeneratedProtocolMessageType('CheckSchedulingConstraintsResponse', (_message.Message,), {

  'ViolatingClass' : _reflection.GeneratedProtocolMessageType('ViolatingClass', (_message.Message,), {
    'DESCRIPTOR' : _CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGCLASS,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.CheckSchedulingConstraintsResponse.ViolatingClass)
    })
  ,

  'ViolatingModule' : _reflection.GeneratedProtocolMessageType('ViolatingModule', (_message.Message,), {
    'DESCRIPTOR' : _CHECKSCHEDULINGCONSTRAINTSRESPONSE_VIOLATINGMODULE,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.CheckSchedulingConstraintsResponse.ViolatingModule)
    })
  ,
  'DESCRIPTOR' : _CHECKSCHEDULINGCONSTRAINTSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.CheckSchedulingConstraintsResponse)
  })
_sym_db.RegisterMessage(CheckSchedulingConstraintsResponse)
_sym_db.RegisterMessage(CheckSchedulingConstraintsResponse.ViolatingClass)
_sym_db.RegisterMessage(CheckSchedulingConstraintsResponse.ViolatingModule)

AddTcRequest = _reflection.GeneratedProtocolMessageType('AddTcRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTCREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.AddTcRequest)
  })
_sym_db.RegisterMessage(AddTcRequest)

UpdateTcParamsRequest = _reflection.GeneratedProtocolMessageType('UpdateTcParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETCPARAMSREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.UpdateTcParamsRequest)
  })
_sym_db.RegisterMessage(UpdateTcParamsRequest)

UpdateTcParentRequest = _reflection.GeneratedProtocolMessageType('UpdateTcParentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETCPARENTREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.UpdateTcParentRequest)
  })
_sym_db.RegisterMessage(UpdateTcParentRequest)

GetTcStatsRequest = _reflection.GeneratedProtocolMessageType('GetTcStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTCSTATSREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetTcStatsRequest)
  })
_sym_db.RegisterMessage(GetTcStatsRequest)

GetTcStatsResponse = _reflection.GeneratedProtocolMessageType('GetTcStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTCSTATSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetTcStatsResponse)
  })
_sym_db.RegisterMessage(GetTcStatsResponse)

ListDriversResponse = _reflection.GeneratedProtocolMessageType('ListDriversResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDRIVERSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListDriversResponse)
  })
_sym_db.RegisterMessage(ListDriversResponse)

GetDriverInfoRequest = _reflection.GeneratedProtocolMessageType('GetDriverInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDRIVERINFOREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetDriverInfoRequest)
  })
_sym_db.RegisterMessage(GetDriverInfoRequest)

GetDriverInfoResponse = _reflection.GeneratedProtocolMessageType('GetDriverInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDRIVERINFORESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetDriverInfoResponse)
  })
_sym_db.RegisterMessage(GetDriverInfoResponse)

ListPortsResponse = _reflection.GeneratedProtocolMessageType('ListPortsResponse', (_message.Message,), {

  'Port' : _reflection.GeneratedProtocolMessageType('Port', (_message.Message,), {
    'DESCRIPTOR' : _LISTPORTSRESPONSE_PORT,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.ListPortsResponse.Port)
    })
  ,
  'DESCRIPTOR' : _LISTPORTSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListPortsResponse)
  })
_sym_db.RegisterMessage(ListPortsResponse)
_sym_db.RegisterMessage(ListPortsResponse.Port)

CreatePortRequest = _reflection.GeneratedProtocolMessageType('CreatePortRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPORTREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.CreatePortRequest)
  })
_sym_db.RegisterMessage(CreatePortRequest)

PortConf = _reflection.GeneratedProtocolMessageType('PortConf', (_message.Message,), {
  'DESCRIPTOR' : _PORTCONF,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.PortConf)
  })
_sym_db.RegisterMessage(PortConf)

SetPortConfRequest = _reflection.GeneratedProtocolMessageType('SetPortConfRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPORTCONFREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.SetPortConfRequest)
  })
_sym_db.RegisterMessage(SetPortConfRequest)

GetPortConfRequest = _reflection.GeneratedProtocolMessageType('GetPortConfRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPORTCONFREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetPortConfRequest)
  })
_sym_db.RegisterMessage(GetPortConfRequest)

GetPortConfResponse = _reflection.GeneratedProtocolMessageType('GetPortConfResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPORTCONFRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetPortConfResponse)
  })
_sym_db.RegisterMessage(GetPortConfResponse)

CreatePortResponse = _reflection.GeneratedProtocolMessageType('CreatePortResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPORTRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.CreatePortResponse)
  })
_sym_db.RegisterMessage(CreatePortResponse)

DestroyPortRequest = _reflection.GeneratedProtocolMessageType('DestroyPortRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESTROYPORTREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DestroyPortRequest)
  })
_sym_db.RegisterMessage(DestroyPortRequest)

GetPortStatsRequest = _reflection.GeneratedProtocolMessageType('GetPortStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPORTSTATSREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetPortStatsRequest)
  })
_sym_db.RegisterMessage(GetPortStatsRequest)

GetPortStatsResponse = _reflection.GeneratedProtocolMessageType('GetPortStatsResponse', (_message.Message,), {

  'Stat' : _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), {
    'DESCRIPTOR' : _GETPORTSTATSRESPONSE_STAT,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.GetPortStatsResponse.Stat)
    })
  ,
  'DESCRIPTOR' : _GETPORTSTATSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetPortStatsResponse)
  })
_sym_db.RegisterMessage(GetPortStatsResponse)
_sym_db.RegisterMessage(GetPortStatsResponse.Stat)

GetLinkStatusRequest = _reflection.GeneratedProtocolMessageType('GetLinkStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLINKSTATUSREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetLinkStatusRequest)
  })
_sym_db.RegisterMessage(GetLinkStatusRequest)

GetLinkStatusResponse = _reflection.GeneratedProtocolMessageType('GetLinkStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLINKSTATUSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetLinkStatusResponse)
  })
_sym_db.RegisterMessage(GetLinkStatusResponse)

ListMclassResponse = _reflection.GeneratedProtocolMessageType('ListMclassResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMCLASSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListMclassResponse)
  })
_sym_db.RegisterMessage(ListMclassResponse)

GetMclassInfoRequest = _reflection.GeneratedProtocolMessageType('GetMclassInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMCLASSINFOREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetMclassInfoRequest)
  })
_sym_db.RegisterMessage(GetMclassInfoRequest)

GetMclassInfoResponse = _reflection.GeneratedProtocolMessageType('GetMclassInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMCLASSINFORESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetMclassInfoResponse)
  })
_sym_db.RegisterMessage(GetMclassInfoResponse)

ListModulesResponse = _reflection.GeneratedProtocolMessageType('ListModulesResponse', (_message.Message,), {

  'Module' : _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODULESRESPONSE_MODULE,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.ListModulesResponse.Module)
    })
  ,
  'DESCRIPTOR' : _LISTMODULESRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListModulesResponse)
  })
_sym_db.RegisterMessage(ListModulesResponse)
_sym_db.RegisterMessage(ListModulesResponse.Module)

CreateModuleRequest = _reflection.GeneratedProtocolMessageType('CreateModuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODULEREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.CreateModuleRequest)
  })
_sym_db.RegisterMessage(CreateModuleRequest)

CreateModuleResponse = _reflection.GeneratedProtocolMessageType('CreateModuleResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODULERESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.CreateModuleResponse)
  })
_sym_db.RegisterMessage(CreateModuleResponse)

DestroyModuleRequest = _reflection.GeneratedProtocolMessageType('DestroyModuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESTROYMODULEREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DestroyModuleRequest)
  })
_sym_db.RegisterMessage(DestroyModuleRequest)

GetModuleInfoRequest = _reflection.GeneratedProtocolMessageType('GetModuleInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODULEINFOREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetModuleInfoRequest)
  })
_sym_db.RegisterMessage(GetModuleInfoRequest)

GetModuleInfoResponse = _reflection.GeneratedProtocolMessageType('GetModuleInfoResponse', (_message.Message,), {

  'GateHook' : _reflection.GeneratedProtocolMessageType('GateHook', (_message.Message,), {
    'DESCRIPTOR' : _GETMODULEINFORESPONSE_GATEHOOK,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.GetModuleInfoResponse.GateHook)
    })
  ,

  'IGate' : _reflection.GeneratedProtocolMessageType('IGate', (_message.Message,), {

    'OGate' : _reflection.GeneratedProtocolMessageType('OGate', (_message.Message,), {
      'DESCRIPTOR' : _GETMODULEINFORESPONSE_IGATE_OGATE,
      '__module__' : 'bess_msg_pb2'
      # @@protoc_insertion_point(class_scope:bess.pb.GetModuleInfoResponse.IGate.OGate)
      })
    ,
    'DESCRIPTOR' : _GETMODULEINFORESPONSE_IGATE,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.GetModuleInfoResponse.IGate)
    })
  ,

  'OGate' : _reflection.GeneratedProtocolMessageType('OGate', (_message.Message,), {
    'DESCRIPTOR' : _GETMODULEINFORESPONSE_OGATE,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.GetModuleInfoResponse.OGate)
    })
  ,

  'Attribute' : _reflection.GeneratedProtocolMessageType('Attribute', (_message.Message,), {
    'DESCRIPTOR' : _GETMODULEINFORESPONSE_ATTRIBUTE,
    '__module__' : 'bess_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.GetModuleInfoResponse.Attribute)
    })
  ,
  'DESCRIPTOR' : _GETMODULEINFORESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetModuleInfoResponse)
  })
_sym_db.RegisterMessage(GetModuleInfoResponse)
_sym_db.RegisterMessage(GetModuleInfoResponse.GateHook)
_sym_db.RegisterMessage(GetModuleInfoResponse.IGate)
_sym_db.RegisterMessage(GetModuleInfoResponse.IGate.OGate)
_sym_db.RegisterMessage(GetModuleInfoResponse.OGate)
_sym_db.RegisterMessage(GetModuleInfoResponse.Attribute)

ConnectModulesRequest = _reflection.GeneratedProtocolMessageType('ConnectModulesRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTMODULESREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ConnectModulesRequest)
  })
_sym_db.RegisterMessage(ConnectModulesRequest)

DisconnectModulesRequest = _reflection.GeneratedProtocolMessageType('DisconnectModulesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTMODULESREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DisconnectModulesRequest)
  })
_sym_db.RegisterMessage(DisconnectModulesRequest)

MempoolDump = _reflection.GeneratedProtocolMessageType('MempoolDump', (_message.Message,), {
  'DESCRIPTOR' : _MEMPOOLDUMP,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.MempoolDump)
  })
_sym_db.RegisterMessage(MempoolDump)

DumpMempoolRequest = _reflection.GeneratedProtocolMessageType('DumpMempoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _DUMPMEMPOOLREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DumpMempoolRequest)
  })
_sym_db.RegisterMessage(DumpMempoolRequest)

DumpMempoolResponse = _reflection.GeneratedProtocolMessageType('DumpMempoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _DUMPMEMPOOLRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DumpMempoolResponse)
  })
_sym_db.RegisterMessage(DumpMempoolResponse)

CommandRequest = _reflection.GeneratedProtocolMessageType('CommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.CommandRequest)
  })
_sym_db.RegisterMessage(CommandRequest)

CommandResponse = _reflection.GeneratedProtocolMessageType('CommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.CommandResponse)
  })
_sym_db.RegisterMessage(CommandResponse)

ListGateHookClassResponse = _reflection.GeneratedProtocolMessageType('ListGateHookClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGATEHOOKCLASSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListGateHookClassResponse)
  })
_sym_db.RegisterMessage(ListGateHookClassResponse)

GetGateHookClassInfoRequest = _reflection.GeneratedProtocolMessageType('GetGateHookClassInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETGATEHOOKCLASSINFOREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetGateHookClassInfoRequest)
  })
_sym_db.RegisterMessage(GetGateHookClassInfoRequest)

GetGateHookClassInfoResponse = _reflection.GeneratedProtocolMessageType('GetGateHookClassInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETGATEHOOKCLASSINFORESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GetGateHookClassInfoResponse)
  })
_sym_db.RegisterMessage(GetGateHookClassInfoResponse)

TrackArg = _reflection.GeneratedProtocolMessageType('TrackArg', (_message.Message,), {
  'DESCRIPTOR' : _TRACKARG,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.TrackArg)
  })
_sym_db.RegisterMessage(TrackArg)

TcpdumpArg = _reflection.GeneratedProtocolMessageType('TcpdumpArg', (_message.Message,), {
  'DESCRIPTOR' : _TCPDUMPARG,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.TcpdumpArg)
  })
_sym_db.RegisterMessage(TcpdumpArg)

PcapngArg = _reflection.GeneratedProtocolMessageType('PcapngArg', (_message.Message,), {
  'DESCRIPTOR' : _PCAPNGARG,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.PcapngArg)
  })
_sym_db.RegisterMessage(PcapngArg)

GateHookInfo = _reflection.GeneratedProtocolMessageType('GateHookInfo', (_message.Message,), {
  'DESCRIPTOR' : _GATEHOOKINFO,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GateHookInfo)
  })
_sym_db.RegisterMessage(GateHookInfo)

ConfigureGateHookRequest = _reflection.GeneratedProtocolMessageType('ConfigureGateHookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREGATEHOOKREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ConfigureGateHookRequest)
  })
_sym_db.RegisterMessage(ConfigureGateHookRequest)

ConfigureGateHookResponse = _reflection.GeneratedProtocolMessageType('ConfigureGateHookResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREGATEHOOKRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ConfigureGateHookResponse)
  })
_sym_db.RegisterMessage(ConfigureGateHookResponse)

ListGateHooksResponse = _reflection.GeneratedProtocolMessageType('ListGateHooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGATEHOOKSRESPONSE,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ListGateHooksResponse)
  })
_sym_db.RegisterMessage(ListGateHooksResponse)

GateHookCommandRequest = _reflection.GeneratedProtocolMessageType('GateHookCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _GATEHOOKCOMMANDREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GateHookCommandRequest)
  })
_sym_db.RegisterMessage(GateHookCommandRequest)

ConfigureResumeHookRequest = _reflection.GeneratedProtocolMessageType('ConfigureResumeHookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURERESUMEHOOKREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ConfigureResumeHookRequest)
  })
_sym_db.RegisterMessage(ConfigureResumeHookRequest)

PauseWorkerRequest = _reflection.GeneratedProtocolMessageType('PauseWorkerRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEWORKERREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.PauseWorkerRequest)
  })
_sym_db.RegisterMessage(PauseWorkerRequest)

ResumeWorkerRequest = _reflection.GeneratedProtocolMessageType('ResumeWorkerRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEWORKERREQUEST,
  '__module__' : 'bess_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ResumeWorkerRequest)
  })
_sym_db.RegisterMessage(ResumeWorkerRequest)


_TRAFFICCLASS_LIMITENTRY._options = None
_TRAFFICCLASS_MAXBURSTENTRY._options = None
# @@protoc_insertion_point(module_scope)
